function [H] = HRenyi_MST_estimation(Y,co)
%Estimates the Rnyi entropy (H) of Y (Y(:,t) is the t^th sample)
%using the minimum spanning tree (MST). Cost parameters are provided in the cost object co.
%
%We make use of the naming convention 'H<name>_estimation', to ease embedding new entropy estimation methods.
%
%REFERENCE: 
%   Barnabs Pczos, Andrs Lrincz: Independent Subspace Analysis Using Geodesic Spanning Trees. ICML-2005, pages 673-680. (application in ISA)
%   Joseph E. Yukich. Probability Theory of Classical Euclidean Optimization Problems, Lecture Notes in Mathematics, 1998, vol. 1675.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

[d,num_of_samples] = size(Y);
gam = d * (1-co.alpha);
W = squareform(pdist(Y.')).^gam; %[ (||Y(:,i)-Y(:,j)||_2).^gam ]

%W->L:
    L = compute_MST(W,co.MSTmethod);
    
%co.mult:OK.

%estimation up to an additive constant:
    H = log(L/num_of_samples^(co.alpha)) / (1-co.alpha);

